@@ -125,7 +125,7 @@ void* pack1D ( SV* arg, char packtype ) {
           uscalar = (unsigned char) SvNV(arg);	/*Get the scalar value */
 	  sv_setpvn(work, (char *) &uscalar, sizeof(char)); /* Pack it in */
       }
-      return (void *) SvPV(work, na);        /* Return the pointer */
+      return (void *) SvPV(work, PL_na);        /* Return the pointer */
    }
    
    /* Is it a glob or reference to an array? */
@@ -189,7 +189,7 @@ void* pack1D ( SV* arg, char packtype ) {
    
       /* Return a pointer to the byte array */
    
-      return (void *) SvPV(work, na);
+      return (void *) SvPV(work, PL_na);
    
    }
    
@@ -259,7 +259,7 @@ void* pack2D ( SV* arg, char packtype ) {
    
    /* Is arg a scalar? Return pointer to char part */
    
-   if (!SvROK(arg) && SvTYPE(arg)!=SVt_PVGV) { return (void *) SvPV(arg, na); }
+   if (!SvROK(arg) && SvTYPE(arg)!=SVt_PVGV) { return (void *) SvPV(arg, PL_na); }
    
    /* 
       Create a work char variable - be cunning and make it a mortal *SV
@@ -352,7 +352,7 @@ void* pack2D ( SV* arg, char packtype ) {
    
       /* Return a pointer to the byte array */
    
-      return (void *) SvPV(work, na);
+      return (void *) SvPV(work, PL_na);
    
    }
    
@@ -409,7 +409,7 @@ void* packND ( SV* arg, char packtype ) {
    
    pack_element(work, &arg, packtype);
    
-   return (void *) SvPV(work, na);
+   return (void *) SvPV(work, PL_na);
 
 }
 
@@ -514,7 +514,6 @@ void unpack1D ( SV* arg, void * var, char packtype, int n ) {
    double* dvar;
    short* svar;
    unsigned char* uvar;
-   double foo;
    SV* work;
    AV* array;
    I32 i,m;
@@ -547,7 +546,6 @@ void unpack1D ( SV* arg, void * var, char packtype, int n ) {
    /* Unpack into the array */
    
    for(i=0; i<m; i++) {
-      foo = (double) fvar[i];
       if (packtype=='i') 
          av_store( array, i, newSViv( (IV)ivar[i] ) );
       if (packtype=='f') 
@@ -639,7 +637,7 @@ void* get_mortalspace( int n, char packtype ) {
    if (packtype=='s')
      SvGROW( work, sizeof(short)*n);
    
-   return (void *) SvPV(work, na);
+   return (void *) SvPV(work, PL_na);
 }
 
 
